.\" Copyright 2009 The Archiveopteryx Developers <info@aox.org>
.TH tlsproxy 8 2010-03-10 aox.org "Archiveopteryx Documentation"
.SH NAME
tlsproxy - TLS/SSL helper for Archiveopteryx.
.SH SYNOPSIS
.B $SBINDIR/tlsproxy [-f] [-c configfile]
.SH DESCRIPTION
.nh
.PP
The Archiveopteryx
.B tlsproxy
is a separate process which performs TLS and SSLv3 processing on behalf of
.BR archiveopteryx (8).
TLS processing is kept separate from these other servers for
architectural reasons:
.PP
TLS occasionally causes processing delays, for example while
regenerating keys. Since most of Archiveopteryx is event-driven, these
delays would block other users.
.PP
Further, there is a lot of code in cryptlib, which we prefer not to
link into all of our servers.
.PP
.B tlsproxy
should always be running when Archiveopteryx is in use, but you should
never need to interact with it directly.
.SH OPTIONS
.IP "-c filename"
Read configuration variables from
.I filename
instead of from
.IR $CONFIGDIR/archiveopteryx.conf .
.IP -f
Fork into background during startup.
.SH CONFIGURATION
.B tlsproxy
is configured using
.BR archiveopteryx.conf (5).
.PP
The configuration variables specific to this server are
.IR use-tls ,
.IR tls-certificate ,
.IR tls-certificate-label ,
.IR tls-certificate-secret ,
.IR tlsproxy-address ,
and
.IR tlsproxy-port .
Other variables may be consulted to determine how to connect to the log
server, how to secure the server, and so on.
.PP
.B tlsproxy
uses a private key and certificate from a PKCS #15 key file. The
location of the key file is specified by
.IR tls-certificate .
The key is uniquely identified by the
.IR tls-certificate-label ,
and encrypted with the
.IR tls-certificate-secret .
.PP
The default configuration enables the use of TLS with an
automatically-generated, self-signed certificate. This certificate is
generated once at startup, stored in
.I $LIBDIR/automatic-key.p15
by default (using the hostname as a certificate label), and reused on
subsequent occasions. If the certificate expires, or becomes unusable
for any reason (e.g. the hostname changes), it will be regenerated the
next time tlsproxy starts up.
.SH DEPENDENCIES
On startup,
.B tlsproxy
needs to be able to connect to
.BR logd .
.SH DIAGNOSTICS
In case of error,
.B tlsproxy
exits with exit code 1, an error message on stderr and (usually more
detailed) information in the log file.
.SH "CERTIFICATE HANDLING"
.B Tlsproxy
can use a proper certificate signed by a CA, as usual. If you
do not have one,
.B tlsproxy
will generate a self-signed certificate at startup. No clients trust
this certificate, but we think it's better to have a self-signed
certificate than to not use TLS.
.PP
We strongly recommend that you get a proper signed certificate. Using
the dynamically generated certificate preserves some of the advantages
of TLS, but far from all.
.PP
If you have a private key in OpenSSL format, you can convert it to a
PKCS #15 key file that
.B tlsproxy
can use with the
.I pemtrans
program, available from
.IR http://toroid.org/ams/pemtrans .
.SH FILES
.IP $LIBDIR/automatic-key.p15
is used to store the automatically generated key and certificate.
.SH AUTHOR
The Archiveopteryx Developers, info@aox.org.
.SH VERSION
This man page covers Archiveopteryx version 3.1.3, released 2010-03-10,
http://www.archiveopteryx.org/3.1.3
.SH SEE ALSO
.BR archiveopteryx (8),
.BR archiveopteryx.conf (5),
.BR deliver (8),
.BR logd (8),
http://www.archiveopteryx.org
